==> kubernetes-model-apiextensions-6.3.1-sources.jar: io/fabric8/kubernetes/api/model/apiextensions/v1beta1/CustomResourceConversionFluent.java <==
package io.fabric8.kubernetes.api.model.apiextensions.v1beta1;

import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface CustomResourceConversionFluent<A extends CustomResourceConversionFluent<A>> extends Fluent<A>{
  public A addToConversionReviewVersions(Integer index,String item);
  public A setToConversionReviewVersions(Integer index,String item);
  public A addToConversionReviewVersions(java.lang.String... items);
  public A addAllToConversionReviewVersions(Collection<String> items);
  public A removeFromConversionReviewVersions(java.lang.String... items);
  public A removeAllFromConversionReviewVersions(Collection<String> items);
  public List<String> getConversionReviewVersions();
  public String getConversionReviewVersion(Integer index);
  public String getFirstConversionReviewVersion();
  public String getLastConversionReviewVersion();
  public String getMatchingConversionReviewVersion(Predicate<String> predicate);
  public Boolean hasMatchingConversionReviewVersion(Predicate<String> predicate);
  public A withConversionReviewVersions(List<String> conversionReviewVersions);
  public A withConversionReviewVersions(java.lang.String... conversionReviewVersions);
  public Boolean hasConversionReviewVersions();
  public String getStrategy();
  public A withStrategy(String strategy);
  public Boolean hasStrategy();
  
  /**
   * This method has been deprecated, please use method buildWebhookClientConfig instead.
   * @return The buildable object.
   */
  @Deprecated
  public WebhookClientConfig getWebhookClientConfig();
  public WebhookClientConfig buildWebhookClientConfig();
  public A withWebhookClientConfig(WebhookClientConfig webhookClientConfig);
  public Boolean hasWebhookClientConfig();
  public CustomResourceConversionFluent.WebhookClientConfigNested<A> withNewWebhookClientConfig();
  public CustomResourceConversionFluent.WebhookClientConfigNested<A> withNewWebhookClientConfigLike(WebhookClientConfig item);
  public CustomResourceConversionFluent.WebhookClientConfigNested<A> editWebhookClientConfig();
  public CustomResourceConversionFluent.WebhookClientConfigNested<A> editOrNewWebhookClientConfig();
  public CustomResourceConversionFluent.WebhookClientConfigNested<A> editOrNewWebhookClientConfigLike(WebhookClientConfig item);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface WebhookClientConfigNested<N> extends Nested<N>,WebhookClientConfigFluent<CustomResourceConversionFluent.WebhookClientConfigNested<N>>{
    public N and();
    public N endWebhookClientConfig();
    
  }
  
}

==> kubernetes-model-apiextensions-6.7.2-sources.jar: io/fabric8/kubernetes/api/model/apiextensions/v1beta1/CustomResourceConversionFluent.java <==
package io.fabric8.kubernetes.api.model.apiextensions.v1beta1;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface CustomResourceConversionFluent<A extends CustomResourceConversionFluent<A>> extends Fluent<A>{
  public A addToConversionReviewVersions(int index,String item);
  public A setToConversionReviewVersions(int index,String item);
  public A addToConversionReviewVersions(java.lang.String... items);
  public A addAllToConversionReviewVersions(Collection<String> items);
  public A removeFromConversionReviewVersions(java.lang.String... items);
  public A removeAllFromConversionReviewVersions(Collection<String> items);
  public List<String> getConversionReviewVersions();
  public String getConversionReviewVersion(int index);
  public String getFirstConversionReviewVersion();
  public String getLastConversionReviewVersion();
  public String getMatchingConversionReviewVersion(Predicate<String> predicate);
  public Boolean hasMatchingConversionReviewVersion(Predicate<String> predicate);
  public A withConversionReviewVersions(List<String> conversionReviewVersions);
  public A withConversionReviewVersions(java.lang.String... conversionReviewVersions);
  public Boolean hasConversionReviewVersions();
  public String getStrategy();
  public A withStrategy(String strategy);
  public Boolean hasStrategy();
  
  /**
   * This method has been deprecated, please use method buildWebhookClientConfig instead.
   * @return The buildable object.
   */
  @Deprecated
  public WebhookClientConfig getWebhookClientConfig();
  public WebhookClientConfig buildWebhookClientConfig();
  public A withWebhookClientConfig(WebhookClientConfig webhookClientConfig);
  public Boolean hasWebhookClientConfig();
  public CustomResourceConversionFluent.WebhookClientConfigNested<A> withNewWebhookClientConfig();
  public CustomResourceConversionFluent.WebhookClientConfigNested<A> withNewWebhookClientConfigLike(WebhookClientConfig item);
  public CustomResourceConversionFluent.WebhookClientConfigNested<A> editWebhookClientConfig();
  public CustomResourceConversionFluent.WebhookClientConfigNested<A> editOrNewWebhookClientConfig();
  public CustomResourceConversionFluent.WebhookClientConfigNested<A> editOrNewWebhookClientConfigLike(WebhookClientConfig item);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface WebhookClientConfigNested<N> extends Nested<N>,WebhookClientConfigFluent<CustomResourceConversionFluent.WebhookClientConfigNested<N>>{
    public N and();
    public N endWebhookClientConfig();
    
  }
  
}
